@@ -1,5 +1,5 @@
 package Authen::OATH;
-$Authen::OATH::VERSION = '2.0.0';
+$Authen::OATH::VERSION = '2.0.1';
 use warnings;
 use strict;
 
@@ -29,7 +29,7 @@ has timestep => (
 
 sub totp {
     my ( $self, $secret, $manual_time ) = @_;
-    $secret = join( "", map chr( hex() ), $secret =~ /(..)/g )
+    $secret = join( "", map chr( hex($_) ), $secret =~ /(..)/g )
         if $secret =~ /^[a-fA-F0-9]{32,}$/;
     my $mod = $self->digest;
     if ( eval "require $mod" ) {
@@ -39,7 +39,7 @@ sub totp {
     my $T = Math::BigInt->new( int( $time / $self->timestep ) );
     die "Must request at least 6 digits" if $self->digits < 6;
     ( my $hex = $T->as_hex ) =~ s/^0x(.*)/"0"x(16 - length $1) . $1/e;
-    my $bin_code = join( "", map chr hex, $hex =~ /(..)/g );
+    my $bin_code = join( "", map chr( hex($_) ), $hex =~ /(..)/g );
     my $otp = $self->_process( $secret, $bin_code );
     return $otp;
 }
@@ -47,7 +47,7 @@ sub totp {
 
 sub hotp {
     my ( $self, $secret, $c ) = @_;
-    $secret = join( "", map chr( hex() ), $secret =~ /(..)/g )
+    $secret = join( "", map chr( hex($_) ), $secret =~ /(..)/g )
         if $secret =~ /^[a-fA-F0-9]{32,}$/;
     my $mod = $self->digest;
     if ( eval "require $mod" ) {
@@ -56,7 +56,7 @@ sub hotp {
     $c = Math::BigInt->new($c);
     die "Must request at least 6 digits" if $self->digits < 6;
     ( my $hex = $c->as_hex ) =~ s/^0x(.*)/"0"x(16 - length $1) . $1/e;
-    my $bin_code = join( "", map chr hex, $hex =~ /(..)/g );
+    my $bin_code = join( "", map chr( hex($_) ), $hex =~ /(..)/g );
     my $otp = $self->_process( $secret, $bin_code );
     return $otp;
 }
@@ -95,7 +95,7 @@ Authen::OATH - OATH One Time Passwords
 
 =head1 VERSION
 
-version 2.0.0
+version 2.0.1
 
 =head1 SYNOPSIS
 
@@ -171,7 +171,7 @@ Kurt Kincaid <kurt.kincaid@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Kurt Kincaid.
+This software is copyright (c) 2010-2017 by Kurt Kincaid.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
